#version 330 core

in vec3 vert_normal;
in vec3 frag_position;

out vec4 color;

uniform vec3 camera_position;
uniform vec3 object_color;
uniform vec3 light_color;
uniform vec3 light_position;

void main() {
  float ambient_strength   = 0.15;
  float specular_strength  = 0.5;
  vec3  normal             = normalize(vert_normal);
  vec3  light_direction    = normalize(light_position - frag_position);
  vec3  view_direction     = normalize(camera_position - frag_position);
  vec3  reflect_direction  = reflect(-light_direction, normal);
  float diff               = max(dot(normal, light_direction), 0.0);
  float spec               = pow(max(dot(reflect_direction, view_direction), 0.0), 32);
  vec3  ambient            = light_color * ambient_strength;
  vec3  diffuse            = diff * light_color;
  vec3  specular           = specular_strength * spec * light_color;

  color = vec4(object_color * (ambient + diffuse + specular), 1.0);
};
